layout

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 11, 2025 License: MIT Imports: 3 Imported by: 1

Documentation

Overview

templ: version: v0.3.819

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Clsx

func Clsx(attrs ...templ.Attributes) templ.Attributes

func Columns

func Columns() templ.Component

Columns is a component that renders a responsive flex container that stacks on mobile

func Container

func Container() templ.Component

func Root

func Root(title string) templ.Component

Layout is a component that renders the general layout of the application

func Rows

func Rows() templ.Component

Rows is a component that renders a responsive flex container that wraps on mobile

func Separator

func Separator(text string) templ.Component

Types

This section is empty.

Jump to